==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property audioHlsRenditionSelection Audio HLS Rendition Selection. See Audio HLS Rendition Selection for more details.
 * @property audioLanguageSelection Audio Language Selection. See Audio Language Selection for more details.
 * @property audioPidSelection Audio Pid Selection. See Audio PID Selection for more details.
 * @property audioTrackSelection Audio Track Selection. See Audio Track Selection for more details.
 */
public data class ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings(
    public val audioHlsRenditionSelection:
    ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioHlsRenditionSelection? =
        null,
    public val audioLanguageSelection:
    ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioLanguageSelection? =
        null,
    public val audioPidSelection:
    ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioPidSelection? = null,
    public val audioTrackSelection:
    ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioTrackSelection? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings):
            ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings =
            ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings(
                audioHlsRenditionSelection = javaType.audioHlsRenditionSelection().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioHlsRenditionSelection.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                audioLanguageSelection = javaType.audioLanguageSelection().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioLanguageSelection.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                audioPidSelection = javaType.audioPidSelection().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioPidSelection.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                audioTrackSelection = javaType.audioTrackSelection().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioTrackSelection.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property audioHlsRenditionSelection Audio HLS Rendition Selection. See Audio HLS Rendition Selection for more details.
 * @property audioLanguageSelection Audio Language Selection. See Audio Language Selection for more details.
 * @property audioPidSelection Audio Pid Selection. See Audio PID Selection for more details.
 * @property audioTrackSelection Audio Track Selection. See Audio Track Selection for more details.
 */
public data class ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings(
    public val audioHlsRenditionSelection: ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioHlsRenditionSelection? =
        null,
    public val audioLanguageSelection: ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioLanguageSelection? =
        null,
    public val audioPidSelection: ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioPidSelection? = null,
    public val audioTrackSelection: ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioTrackSelection? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings): ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings =
            ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettings(
                audioHlsRenditionSelection = javaType.audioHlsRenditionSelection().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioHlsRenditionSelection.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                audioLanguageSelection = javaType.audioLanguageSelection().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioLanguageSelection.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                audioPidSelection = javaType.audioPidSelection().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioPidSelection.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                audioTrackSelection = javaType.audioTrackSelection().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelInputAttachmentInputSettingsAudioSelectorSelectorSettingsAudioTrackSelection.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
